var Remote = function()
{
	var remote = {};
	var files;
	var debug = 1;
	
	remote.initPage = function()
	{
		Buttons.addClickHandler('close', App.closeWindow);
		Buttons.addClickHandler('btnSaveToBase', remote.saveToBase);
		
		var url = '../OpenGrid.servlet?ID='+App.getSessionId();
		url += '&cmd=ListProjectFiles';
		url += '&clusterId='+Data.get('page-data', 'cluster-id');
		url += '&path='+encodeURIComponent(Data.get('page-data', 'path'));
		url += '&itemType='+Data.get('page-data', 'item-type');
		url += '&itemId='+Data.get('page-data', 'item-id');
		var request = Ajax.getXmlHttpRequest();
		showLoadingAnimation('Loading files...');
		request.open("GET", url, true);
		Ajax.setReadyStateHandler(request, remote.onFilesLoaded, remote.onFilesLoaded);
		request.send(null);
	}
	
	remote.onFilesLoaded = function(request)
	{
		hideLoadingAnimation();
		if (debug) App.debug(Strings.encodeTags(request.responseText));
		
		var response;
		var error = false;
		try
		{
			response = JSON.parse(request.responseText);
			if (response.status != 'ok')
			{
				error = response.message || response.stacktrace || 'Unexpected error';
			}
			else
			{
				files = response.files;
				if (files.length == 0)
				{
					error = 'Could not find any files in folder ' + response.projectArchive +'/'+ Data.get('page-data', 'path');
				}
			}
		}
		catch (ex)
		{
			error = ex;
		}
		if (error)
		{
			Doc.element('errorMessage').innerHTML = error;
			Doc.show('errorMessage');
			Doc.hide('btnSaveToBase');
			return;
		}

		var html = '<table id="file-list">';
		html += '<tr>';
		html += '<th></th>';
		html += '<th>Folder / file</th>';
		html += '<th class="file-size">Size</th>';
		html += '<th></th>';
		html += '</tr>';
		var currentFolder = '-';
		for (var fileNo = 0; fileNo < files.length; fileNo++)
		{
			var file = files[fileNo];
			var path = file.path;
			var i = path.lastIndexOf('/');
			
			var folder = (i > 0) ? path.substring(0, i) : '.';
			var filename = path.substring(i+1);
			file.folder = folder;
			file.name = filename;
			
			if (folder != currentFolder)
			{
				html += '<tr class="folder">';
				html += '<td>';
				html += '<span class="link select-folder" data-folder="'+Strings.encodeTags(folder)+'" title="Select all files">';
				html += '<img src="../images/remote_folder.png"></span></td>';
				html += '<td colspan="3">'+Strings.encodeTags(folder)+'</td>';
				html += '</tr>';
				currentFolder = folder;
			}
			
			html += '<tr class="file highlight">';
			html += '<td><input type="checkbox" data-file-no="'+fileNo+'"></td>';
			html += '<td class="file-name">'+Strings.encodeTags(file.name)+'</td>';
			html += '<td class="file-size">'+Numbers.formatBytes(file.size)+'</td>';
			html += '<td>';
			html += '<span class="link download-file" data-file-no="'+fileNo+'" title="Download this file to your local computer"><img src="../images/download.png"></span>';
			html += '</td>';
			html += '</tr>';
		}
		html += '</table>';
		setInnerHTML('files', html);

		var folders = document.getElementsByClassName('select-folder');
		for (var folderNo = 0; folderNo < folders.length; folderNo++)
		{
			Events.addEventHandler(folders[folderNo], 'click', remote.selectFolder);
		}
		
		var downloadable = document.getElementsByClassName('download-file');
		for (var fileNo = 0; fileNo < downloadable.length; fileNo++)
		{
			Events.addEventHandler(downloadable[fileNo], 'click', remote.downloadFile);
		}
	}
	
	remote.selectFolder = function(event)
	{
		var folder = Data.get(event.currentTarget, 'folder');
		var frm = document.forms['reggie'];
		
		var first = null;
		for (var i = 0; i < frm.elements.length; i++)
		{
			var element = frm.elements[i];
			var fileNo = Data.int(element, 'file-no', null);
			if (element.type == 'checkbox' && fileNo != null && files[fileNo].folder == folder)
			{
				if (first == null)
				{
					first = element;
					element.checked = !element.checked;
				}
				else
				{
					element.checked = first.checked;
				}
			}
		}
	}
	
	remote.downloadFile = function(event)
	{
		var fileNo = Data.get(event.currentTarget, 'file-no');
		var file = files[fileNo];
		var path = Data.get('page-data', 'path')+'/'+file.path;
		
		var url = '../OpenGrid.servlet?ID='+App.getSessionId();
		url += '&cmd=DownloadProjectFile';
		url += '&clusterId='+encodeURIComponent(Data.get('page-data', 'cluster-id'));
		url += '&path='+encodeURIComponent(path);
		url += '&size='+file.size;
		
		location.href = url;
	}
	
	remote.saveToBase = function(event)
	{
		var frm = document.forms['reggie'];
		
		var numChecked = remote.getSelectedFiles().length;
		if (numChecked == 0)
		{
			Forms.showNotification(frm.elements[0], 'Please select at least one file.', null, 'pointer-below');
			return;
		}

		var url = 'save_remote_files.jsp?ID='+App.getSessionId();
		url += '&clusterId='+encodeURIComponent(Data.get('page-data', 'cluster-id'));
		url += '&path='+Data.get('page-data', 'path');
		url += '&itemType='+Data.get('page-data', 'item-type');
		url += '&itemId='+Data.get('page-data', 'item-id');
		Dialogs.openPopup(url, 'SaveToBase', 600, 400);
	}
	
	remote.getSelectedFiles = function()
	{
		var frm = document.forms['reggie'];
		var selected = [];
		for (var i = 0; i < frm.elements.length; i++)
		{
			var element = frm.elements[i];
			var fileNo = Data.get(element, 'file-no', null);
			if (element.type == 'checkbox' && element.checked && fileNo != null)
			{
				selected[selected.length] = files[fileNo];
			}
		}
		return selected;
	}
	
	return remote;
}();

Doc.onLoad(Remote.initPage);
